/*! vite-vue 2017-05-11 */

const store=new Vuex.Store({state:{active:[],pageTitle:""},mutations:{activate:function(a,b,c){if(console.log("MUT * ACTIVATE",b),c)for(i=0;i<b.length;i++)console.log("EL",b[i]),a.active.push(b[i]);else a.active=b;console.log("END",a.active)},deactivate:function(a,b){for(i=0;i<a.active.length;i++)if(b[i]===a.active[i]){var c=a.active.indexOf(b[i]);a.active.splice(c,1)}},setPageTitle:function(a,b){a.pageTitle=b},fillSidebar:function(a,b){a.sidebar=b}},actions:{activate:function(a,b){a.commit("activate",b)},deactivate:function(a,b){a.commit("deactivate",b)},setPageTitle:function(a,b){a.commit("setPageTitle",b)},fillSidebar:function(a,b){a.commit("fillSidebar",b)}},getters:{active:function(a){return a.active},pageTitle:function(a){return a.pageTitle},sidebar:function(a){return a.sidebar}}});