{% load i18n staticfiles instant_tags %}

<script src="{% static 'instant/js/sockjs.min.js' %}" type="text/javascript"></script>
<script src="{% static 'instant/js/centrifuge.js' %}" type="text/javascript"></script>
<script type="text/javascript">
	{% include "instant/js/handlers.js" %}
	{% include "instant/js/client.js" %}
</script>