{% load instant_tags i18n %}
<div style="text-align:center">
	{% get_channels as channels %}
	<div id="chans" class="inline" v-show="instantForm" style="display:none">Channels:
		{% for channel in channels %}
			<span id="{{ channel }}" class="label label-default chan" @click="activateChannel('{{ channel }}')">
				{{ channel }}
			</span>
		{% endfor %}
	</div>
	<div class="pull-right">
		<a id="instant_open" v-on:click="toggleInstantForm()" v-if="instantForm">
			<i class="fa fa-close"></i>&nbsp;{% trans "Close" %}
		</a>
		<a  href="#" id="instant_close" v-on:click="toggleInstantForm()" v-if="(!instantForm)">
			<i class="fa fa-flash"></i>&nbsp;{% trans "Publish" %}
		</a>
	</div>
</div>
