{% load staticfiles %}

<div id="topbar">
	<div id="instant_msgs" style="display:none;font-size:160%">
		{% verbatim %}
		<a href="" v-if="(numMsgs>0)">
			<i v-bind:class="msgIconClass"></i>&nbsp;{{numMsgs}}
		</a>
		{% endverbatim %}
	</div>
</div>
<div class="gds-s" style="display:inline-block;position:relative;top:11px;left:2em;font-size:220%;color:white">
	<span class="hidden-xxs">
		<a href="/">Django Instant</a>
	</span>
</div>