/* ##################################### Base tags ##################################### */
body  {
	background-color:#fff;
    margin: 0;
    padding: 0; 
}
a, a:hover, a:visited {
	text-decoration:none !important;
}
a:not(.btn), a:visited:not(.btn) {
	color:darkslategrey;
}
a:hover:not(.btn) {
	color:grey;
}
h1, h2, h3, h4, h5 {
	color:darkslategrey;
}
img {
	vertical-align:middle;
}
div {
	box-sizing: border-box;
	vertical-align:top;
}
/* ##################################### Skeleton ##################################### */
#site_header {
	min-height:80px;
	background-color:steelblue;
}
#site_header a, #site_header a:visited, #navbar a, #navbar a:visited {
	color:white !important;
	padding-right:0.8em;
}
#topbar {
	position:absolute;
	top:1em;
	right:1em;
}
#topbar a:hover {
	color:grey !important;
}
#navbar .list-inline a:hover, #navbar .list-inline a.active {
	color:darkslategrey !important;
	background-color:white;
}
#navbar {
	background-color:grey;
	padding:0 0 0 6em;
	height:2.9em;
	line-height:2.9em;
	color:white;
}
#navbar .btn {
	padding:0.9em 0.4em 0.9em 0.4em;
	vertical-align:baseline;
}
#chans {
	display:inline-block;
}
#content {
	min-height:40em;
	padding:0.5em 1em 4em 1em;
	align-items:flex-start;
	justify-content:flex-start;
}
#footer {
	min-height:50px;
	background-color:steelblue;
}
/* ##################################### Widgets ##################################### */
.checkbox-slider input+span,.checkbox-toggle input+span{cursor:pointer;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none}.checkbox-slider input[type=checkbox]:focus+:before,.checkbox-slider--a input[type=checkbox]:focus+:before,.checkbox-slider--a-rounded input[type=checkbox]:focus+:before,.checkbox-slider--b input[type=checkbox]:focus+:before,.checkbox-slider--b-flat input[type=checkbox]:focus+:before,.checkbox-slider--c input[type=checkbox]:focus+:before,.checkbox-slider--c-weight input[type=checkbox]:focus+:before,.checkbox-slider--default input[type=checkbox]:focus+:before,.checkbox-toggle input[type=checkbox]:focus+:before{outline:#66afe9 solid 2px}@keyframes popIn{0%,100%{transform:scale(1,1)}25%{transform:scale(1.2,1)}50%{transform:scale(1.4,1)}}@keyframes popOut{0%,100%{transform:scale(1,1)}25%{transform:scale(1.2,1)}50%{transform:scale(1.4,1)}}@keyframes splashIn{0%,100%{transform:scale(1);opacity:1}25%{transform:scale(1.1);opacity:.8}50%{transform:scale(1.1);opacity:.9}}@keyframes splashOut{0%{transform:scale(1);opacity:1}25%{transform:scale(1);opacity:.8}50%{transform:scale(1);opacity:.9}100%{transform:scale(.5);opacity:1}}.checkbox-toggle{position:relative}.checkbox-toggle input[type=checkbox]{display:block;position:absolute;top:0;right:0;bottom:0;left:0;width:0;height:0%;margin:0;cursor:pointer;opacity:0}.checkbox-toggle input+span{user-select:none}.checkbox-toggle input+span:before{position:absolute;left:0;display:inline-block}.checkbox-toggle input+span>h4{display:inline}.form-horizontal [class^=checkbox] input+span:after{top:7px}.checkbox-slider{position:relative}.checkbox-slider input[type=checkbox]{display:block;position:absolute;top:0;right:0;bottom:0;left:0;width:0;height:0%;margin:0;cursor:pointer;opacity:0}.checkbox-slider input+span:after,.checkbox-slider input+span:before{height:20px;position:absolute;content:"";left:0}.checkbox-slider input+span{user-select:none;padding-left:40px}.checkbox-slider--a-rounded input+span,.checkbox-slider--default input+span{cursor:pointer;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;padding-left:40px}.checkbox-slider input+span:before{display:inline-block;width:40px;background:rgba(100,100,100,.2);box-shadow:inset 0 0 5px rgba(0,0,0,.8);transition:background .2s ease-out}.checkbox-slider input+span>h4{display:inline}.checkbox-slider input+span:after{width:20px;top:0;display:block;background:#FFF;transition:margin-left .1s ease-in-out;text-align:center;font-weight:700}.checkbox-slider input:checked+span:after{margin-left:20px;content:""}.checkbox-slider input:checked+span:before{transition:background .2s ease-in}.checkbox-slider--default{position:relative}.checkbox-slider--default input[type=checkbox]{display:block;position:absolute;top:0;right:0;bottom:0;left:0;width:0;height:0%;margin:0;cursor:pointer;opacity:0}.checkbox-slider--default input+span{user-select:none}.checkbox-slider--default input+span:before{position:absolute;left:0;display:inline-block;content:"";height:20px;width:40px;background:rgba(100,100,100,.2);box-shadow:inset 0 0 5px rgba(0,0,0,.8);transition:background .2s ease-out}.checkbox-slider--default input+span>h4{display:inline}.checkbox-slider--default input+span:after{width:20px;height:20px;position:absolute;left:0;top:0;display:block;transition:margin-left .1s ease-in-out;text-align:center;font-weight:700;content:"";background:#FFF;border:1px solid transparent;background-clip:content-box}.checkbox-slider--default input:checked+span:after{margin-left:20px;content:"";background:#5cb85c;border:1px solid transparent;background-clip:content-box}.checkbox-slider--default input:checked+span:before{transition:background .2s ease-in}.checkbox-slider--a-rounded{position:relative}.checkbox-slider--a-rounded input[type=checkbox]{display:block;position:absolute;top:0;right:0;bottom:0;left:0;width:0;height:0%;margin:0;cursor:pointer;opacity:0}.checkbox-slider--a-rounded input+span{user-select:none}.checkbox-slider--a input+span,.checkbox-slider--b input+span{cursor:pointer;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none}.checkbox-slider--a-rounded input+span:before{position:absolute;left:0;display:inline-block;content:"";height:20px;width:40px;background:rgba(100,100,100,.2);box-shadow:inset 0 0 5px rgba(0,0,0,.8);transition:background .2s ease-out}.checkbox-slider--a-rounded input+span>h4{display:inline}.checkbox-slider--a-rounded input+span:after{width:20px;height:20px;position:absolute;left:0;top:0;display:block;transition:margin-left .1s ease-in-out;text-align:center;font-weight:700;content:"";background:#FFF}.checkbox-slider--a-rounded input:checked+span:after{margin-left:20px;content:"";background:#5cb85c}.checkbox-slider--a-rounded input:checked+span:before{transition:background .2s ease-in}.checkbox-slider--a-rounded input+span:after,.checkbox-slider--a-rounded input+span:before{border-radius:4px}.checkbox-slider--a-rounded input+span:after,.checkbox-slider--a-rounded input:checked+span:after{border:2px solid transparent;background-clip:content-box}.checkbox-slider--a-rounded.checkbox-slider-sm input+span:after,.checkbox-slider--a-rounded.checkbox-slider-sm input+span:before{border-radius:3px}.checkbox-slider--a-rounded.checkbox-slider-md input+span:after,.checkbox-slider--a-rounded.checkbox-slider-md input+span:before{border-radius:4px}.checkbox-slider--a-rounded.checkbox-slider-lg input+span:after,.checkbox-slider--a-rounded.checkbox-slider-lg input+span:before{border-radius:6px}.checkbox-slider--a{position:relative}.checkbox-slider--a input[type=checkbox]{display:block;position:absolute;top:0;right:0;bottom:0;left:0;width:0;height:0%;margin:0;cursor:pointer;opacity:0}.checkbox-slider--a input+span{user-select:none;padding-left:60px}.checkbox-slider--a input+span:before{position:absolute;left:0;display:inline-block;height:20px;background:rgba(100,100,100,.2);box-shadow:inset 0 0 5px rgba(0,0,0,.8);transition:background .2s ease-out;content:"";width:60px}.checkbox-slider--a input+span>h4{display:inline}.checkbox-slider--a input+span:after{height:20px;position:absolute;left:0;top:0;display:block;background:#FFF;transition:margin-left .1s ease-in-out;text-align:center;font-weight:700;width:40px;font-size:10px;color:#000;content:"Off";border:1px solid transparent;background-clip:content-box}.checkbox-slider--a input:checked+span:after{margin-left:20px;content:"On";color:#fff;background:#5cb85c;border:1px solid transparent;background-clip:content-box}.checkbox-slider--a input:checked+span:before{transition:background .2s ease-in}.checkbox-slider--a.checkbox-slider-sm input+span{padding-left:30px}.checkbox-slider--a.checkbox-slider-sm input+span:before{width:30px}.checkbox-slider--a.checkbox-slider-sm input+span:after{width:20px;font-size:5px}.checkbox-slider--a.checkbox-slider-sm input:checked+span:after{margin-left:10px}.checkbox-slider--a.checkbox-slider-md input+span{padding-left:90px}.checkbox-slider--a.checkbox-slider-md input+span:before{width:90px}.checkbox-slider--a.checkbox-slider-md input+span:after{width:60px;font-size:15px}.checkbox-slider--a.checkbox-slider-md input:checked+span:after{margin-left:30px}.checkbox-slider--a.checkbox-slider-lg input+span{padding-left:120px}.checkbox-slider--a.checkbox-slider-lg input+span:before{width:120px}.checkbox-slider--a.checkbox-slider-lg input+span:after{width:80px;font-size:20px}.checkbox-slider--a.checkbox-slider-lg input:checked+span:after{margin-left:40px}.checkbox-slider--b{position:relative}.checkbox-slider--b input[type=checkbox]{display:block;position:absolute;top:0;right:0;bottom:0;left:0;width:0;height:0%;margin:0;cursor:pointer;opacity:0}.checkbox-slider--b input+span:after,.checkbox-slider--b input+span:before{height:20px;position:absolute;left:0;content:""}.checkbox-slider--b input+span{user-select:none;padding-left:40px}.checkbox-slider--b-flat input+span,.checkbox-slider--c input+span{-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;cursor:pointer;padding-left:40px}.checkbox-slider--b input+span:before{display:inline-block;background:rgba(100,100,100,.2);box-shadow:inset 0 0 5px rgba(0,0,0,.8);transition:background .2s ease-out;border-radius:20px;width:40px}.checkbox-slider--b input+span>h4{display:inline}.checkbox-slider--b input+span:after{top:0;display:block;transition:margin-left .1s ease-in-out;text-align:center;font-weight:700;background:#FFF;width:20px;border:2px solid transparent;background-clip:padding-box;border-radius:20px}.checkbox-slider--b input:not(:checked)+span:after{animation:popOut ease-in .3s normal}.checkbox-slider--b input:checked+span:after{content:"";margin-left:20px;border:2px solid transparent;background-clip:padding-box;animation:popIn ease-in .3s normal}.checkbox-slider--b input:checked+span:before{transition:background .2s ease-in;background:#5cb85c}.checkbox-slider--b.checkbox-slider-md input+span:after,.checkbox-slider--b.checkbox-slider-md input+span:before{border-radius:30px}.checkbox-slider--b.checkbox-slider-lg input+span:after,.checkbox-slider--b.checkbox-slider-lg input+span:before{border-radius:40px}.checkbox-slider--b-flat{position:relative}.checkbox-slider--b-flat input[type=checkbox]{display:block;position:absolute;top:0;right:0;bottom:0;left:0;width:0;height:0%;margin:0;cursor:pointer;opacity:0}.checkbox-slider--b-flat input+span{user-select:none}.checkbox-slider--b-flat input+span:before{position:absolute;left:0;display:inline-block;content:"";height:20px;background:rgba(100,100,100,.2);transition:background .2s ease-out;border-radius:20px;width:40px;box-shadow:none}.checkbox-slider--b-flat input+span>h4{display:inline}.checkbox-slider--b-flat input+span:after{height:20px;position:absolute;left:0;top:0;display:block;transition:margin-left .1s ease-in-out;text-align:center;font-weight:700}.checkbox-slider--b-flat input+span:after{background:#FFF;content:"";width:20px;border:2px solid transparent;background-clip:padding-box;border-radius:20px}.checkbox-slider--b-flat input:not(:checked)+span:after{animation:popOut ease-in .3s normal}.checkbox-slider--b-flat input:checked+span:after{content:"";margin-left:20px;border:2px solid transparent;background-clip:padding-box;animation:popIn ease-in .3s normal}.checkbox-slider--b-flat input:checked+span:before{transition:background .2s ease-in;background:#5cb85c}.checkbox-slider--b-flat.checkbox-slider-md input+span:after,.checkbox-slider--b-flat.checkbox-slider-md input+span:before{border-radius:30px}.checkbox-slider--b-flat.checkbox-slider-lg input+span:after,.checkbox-slider--b-flat.checkbox-slider-lg input+span:before{border-radius:40px}.checkbox-slider--c{position:relative}.checkbox-slider--c input[type=checkbox]{display:block;position:absolute;top:0;right:0;bottom:0;left:0;width:0;height:0%;margin:0;cursor:pointer;opacity:0}.checkbox-slider--c input+span{user-select:none}.checkbox-slider--c input+span:before{position:absolute;left:0;display:inline-block;content:"";transition:background .2s ease-out}.checkbox-slider--c input+span>h4{display:inline}.checkbox-slider--c input+span:after{height:20px;position:absolute;left:0;top:0;display:block;background:#FFF;transition:margin-left .1s ease-in-out;text-align:center;font-weight:700;content:""}.checkbox-slider--c input+span:before{height:2px!important;top:10px;box-shadow:none;width:40px;background:#555}.checkbox-slider--c input+span:after{box-shadow:none;width:20px;border:2px solid #555;border-radius:20px}.checkbox-slider--c input:checked+span:after{content:"";background:#5cb85c;margin-left:20px;border:2px solid #5cb85c;animation:splashIn ease-in .3s normal}.checkbox-slider--c input:checked+span:before{transition:background .2s ease-in;background:#5cb85c}.checkbox-slider--c.checkbox-slider-sm input+span:before{top:4px}.checkbox-slider--c.checkbox-slider-md input+span:before{top:14px}.checkbox-slider--c.checkbox-slider-md input+span:after{width:30px;border-radius:30px}.checkbox-slider--c.checkbox-slider-lg input+span:before{top:19px}.checkbox-slider--c.checkbox-slider-lg input+span:after{width:40px;border-radius:40px}.form-horizontal [class*=checkbox-slider--c].checkbox-slider-sm input+span:before{top:10px}.form-horizontal [class*=checkbox-slider--c].checkbox-slider-md input+span:before{top:20px}.form-horizontal [class*=checkbox-slider--c].checkbox-slider-lg input+span:before{top:25px}.checkbox-slider--c-weight{position:relative}.checkbox-slider--c-weight input[type=checkbox]{display:block;position:absolute;top:0;right:0;bottom:0;left:0;width:0;height:0%;margin:0;cursor:pointer;opacity:0}.checkbox-slider--c-weight input+span{cursor:pointer;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;padding-left:40px}.checkbox-slider--c-weight input+span:before{position:absolute;left:0;display:inline-block;content:"";transition:background .2s ease-out}.checkbox-slider--c-weight input+span>h4{display:inline}.checkbox-slider--c-weight input+span:after{height:20px;position:absolute;left:0;top:0;display:block;background:#FFF;transition:margin-left .1s ease-in-out;text-align:center;font-weight:700;content:""}.checkbox-slider--c-weight input+span:before{top:10px;box-shadow:none;width:40px;background:#555;height:1px!important}.checkbox-slider--c-weight input+span:after{box-shadow:none;width:20px;border:2px solid #555;border-radius:20px}.checkbox-slider--a input:disabled+span:before,.checkbox-slider--b input:disabled+span:before,.checkbox-slider--default input:disabled+span:before{box-shadow:0 0 0 #000}.checkbox-slider--c-weight input:checked+span:after{content:"";background:#5cb85c;margin-left:20px;border:2px solid #5cb85c;animation:splashIn ease-in .3s normal}.checkbox-slider--c-weight input:checked+span:before{transition:background .2s ease-in;background:#5cb85c;height:2px!important}.checkbox-slider--c input:disabled+span:before,.checkbox-slider--c input:disabled:checked+span:after,.checkbox-slider--default input:disabled+span:after{background:#777}.checkbox-slider--c-weight.checkbox-slider-sm input+span:before{top:4px}.checkbox-slider--c-weight.checkbox-slider-md input+span:before{top:14px}.checkbox-slider--c-weight.checkbox-slider-md input+span:after{width:30px;border-radius:30px}.checkbox-slider--c-weight.checkbox-slider-lg input+span:before{top:19px}.checkbox-slider--c-weight.checkbox-slider-lg input+span:after{width:40px;border-radius:40px}.checkbox-slider--c-weight input:not(:checked)+span:after{transform:scale(.7);left:-6px}.checkbox-slider--default input:disabled+span{color:#777}.checkbox-slider--a input:disabled+span:after{background:#777;color:#FFF}.checkbox-slider--a input:disabled+span,.checkbox-slider--b input:disabled+span,.checkbox-slider--c input:disabled+span{color:#777}.checkbox-slider--b input:disabled+span:after{border:2px solid transparent;border-radius:40px}.checkbox-slider--c input:disabled+span:after{border-color:#777}input:checked+.indicator-success{color:#5cb85c}input:checked+.indicator-info{color:#5bc0de}input:checked+.indicator-warning{color:#f0ad4e}input:checked+.indicator-danger{color:#d9534f}.checkbox-slider-sm{line-height:10px}.checkbox-slider-sm input+span{padding-left:20px}.checkbox-slider-sm input+span:before{width:20px}.checkbox-slider-sm input+span:after,.checkbox-slider-sm input+span:before{height:10px;line-height:10px}.checkbox-slider-sm input+span:after{width:10px;vertical-align:middle}.checkbox-slider-sm input:checked+span:after{margin-left:10px}.checkbox-slider-md{line-height:30px}.checkbox-slider-md input+span{padding-left:60px}.checkbox-slider-md input+span:before{width:60px}.checkbox-slider-md input+span:after,.checkbox-slider-md input+span:before{height:30px;line-height:30px}.checkbox-slider-md input+span:after{width:30px;vertical-align:middle}.checkbox-slider-md input:checked+span:after{margin-left:30px}.checkbox-slider-lg{line-height:40px}.checkbox-slider-lg input+span{padding-left:80px}.checkbox-slider-lg input+span:before{width:80px}.checkbox-slider-lg input+span:after,.checkbox-slider-lg input+span:before{height:40px;line-height:40px}.checkbox-slider-lg input+span:after{width:40px;vertical-align:middle}.checkbox-slider-lg input:checked+span:after{margin-left:40px}.checkbox-slider-info.checkbox-slider--a input:checked+span:after,.checkbox-slider-info.checkbox-slider--a-rounded input:checked+span:after,.checkbox-slider-info.checkbox-slider--c input:checked+span:after,.checkbox-slider-info.checkbox-slider--c-weight input:checked+span:after,.checkbox-slider-info.checkbox-slider--default input:checked+span:after{background:#5bc0de;background-clip:content-box}.checkbox-slider-info.checkbox-slider--c input:checked+span:after,.checkbox-slider-info.checkbox-slider--c-weight input:checked+span:after{border-color:#5bc0de}.checkbox-slider-info.checkbox-slider--b input:checked+span:before,.checkbox-slider-info.checkbox-slider--b-flat input:checked+span:before,.checkbox-slider-info.checkbox-slider--c input:checked+span:before,.checkbox-slider-info.checkbox-slider--c-weight input:checked+span:before{background:#5bc0de}.checkbox-slider-warning.checkbox-slider--a input:checked+span:after,.checkbox-slider-warning.checkbox-slider--a-rounded input:checked+span:after,.checkbox-slider-warning.checkbox-slider--c input:checked+span:after,.checkbox-slider-warning.checkbox-slider--c-weight input:checked+span:after,.checkbox-slider-warning.checkbox-slider--default input:checked+span:after{background:#f0ad4e;background-clip:content-box}.checkbox-slider-warning.checkbox-slider--c input:checked+span:after,.checkbox-slider-warning.checkbox-slider--c-weight input:checked+span:after{border-color:#f0ad4e}.checkbox-slider-warning.checkbox-slider--b input:checked+span:before,.checkbox-slider-warning.checkbox-slider--b-flat input:checked+span:before,.checkbox-slider-warning.checkbox-slider--c input:checked+span:before,.checkbox-slider-warning.checkbox-slider--c-weight input:checked+span:before{background:#f0ad4e}.checkbox-slider-danger.checkbox-slider--a input:checked+span:after,.checkbox-slider-danger.checkbox-slider--a-rounded input:checked+span:after,.checkbox-slider-danger.checkbox-slider--c input:checked+span:after,.checkbox-slider-danger.checkbox-slider--c-weight input:checked+span:after,.checkbox-slider-danger.checkbox-slider--default input:checked+span:after{background:#d9534f;background-clip:content-box}.checkbox-slider-danger.checkbox-slider--c input:checked+span:after,.checkbox-slider-danger.checkbox-slider--c-weight input:checked+span:after{border-color:#d9534f}.checkbox-slider-danger.checkbox-slider--b input:checked+span:before,.checkbox-slider-danger.checkbox-slider--b-flat input:checked+span:before,.checkbox-slider-danger.checkbox-slider--c input:checked+span:before,.checkbox-slider-danger.checkbox-slider--c-weight input:checked+span:before{background:#d9534f}
#sidebar {
	max-width:25%;
	flex-flow: column wrap;
}
#sidebar > div {
	align-items:flex-start;
	justify-content:flex-start;
}
.flex {
	display:flex;
}
.grow {
	flex-grow:1;
}
.start {
	justify-content:flex-start;
}
.hidden {
	display:none;
}
.pad {
	padding:1em;
}
#msg_status {
	display:inline-block;
	margin:0.2em 1em 0 0.5em;
}
.chan {
	margin:0.5em 1em 0.5em 0.5em;
	display:inline-block;
}
.event-label {
	margin-right:0.5em;
	opacity:0.6;
}
.event-labels {
	padding:0.5em;
	margin:0 0 0 2em;
	min-height:3.2em;
}
.full {
	width:100%;
}
.inline {
	display:inline-block;
}
.disabled {
	opacity:0.6;
}
#submitMsg {
	position:relative;
	top:-0.4em;
}
.pull-left {
	float:left
}
.pull-right {
	float:right
}
